/*  Copyright (C) 2008 National Institute For Space Research (INPE) - Brazil.

    This file is part of the TerraLib - a Framework for building GIS enabled applications.

    TerraLib is free software: you can redistribute it and/or modify
    it under the terms of the GNU Lesser General Public License as published by
    the Free Software Foundation, either version 3 of the License,
    or (at your option) any later version.

    TerraLib is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
    GNU Lesser General Public License for more details.

    You should have received a copy of the GNU Lesser General Public License
    along with TerraLib. See COPYING. If not, write to
    TerraLib Team at <terralib-team@terralib.org>.
 */

/*!
  \file terralib/qt/widgets/rp/SegmenterAdvancedOptionsWizardPage.h

  \brief This file defines a class for a Segmenter Advanced Options Wizard page.
*/

#ifndef __TERRALIB_QT_WIDGETS_RP_INTERNAL_SEGMENTERADVANCEDOPTIONSWIZARDPAGE_H
#define __TERRALIB_QT_WIDGETS_RP_INTERNAL_SEGMENTERADVANCEDOPTIONSWIZARDPAGE_H

// TerraLib
#include "../Config.h"
#include "../../../raster/Raster.h"
#include "../../../common/progress/ProgressManager.h"
#include "../../../dataaccess/datasource/DataSource.h"
#include "../../../dataaccess/datasource/DataSourceInfoManager.h"
#include "../../../dataaccess/datasource/DataSourceManager.h"
#include "../../../dataaccess/utils/Utils.h"
#include "../../../datatype/SimpleProperty.h"
#include "../../../geometry/GeometryProperty.h"
#include "../../../memory/DataSet.h"
#include "../../../memory/DataSetItem.h"
#include "../../widgets/layer/utils/DataSet2Layer.h"
#include "../progress/ProgressViewerDialog.h"

// STL
#include <memory>

// Qt
#include <QWizardPage>

// Forward declaration
namespace Ui { class SegmenterAdvancedOptionsWizardPageForm; }

namespace te
{
  namespace qt
  {
    namespace widgets
    {
      /*!
        \class SegmenterAdvancedOptionsWizardPage

        \brief This class is GUI used to define the segmenter advanced options parameters for the RP constast operation.
      */
      class TEQTWIDGETSEXPORT SegmenterAdvancedOptionsWizardPage : public QWizardPage
      {
          Q_OBJECT

        public:

          SegmenterAdvancedOptionsWizardPage(QWidget* parent = 0);

          ~SegmenterAdvancedOptionsWizardPage();

        public:

          Ui::SegmenterAdvancedOptionsWizardPageForm* getForm() const;

          void applyVectorization();

          void set(te::map::AbstractLayerPtr layer);

          void setOutputLayerPath(const std::string& path);

          void setOutputLayerName(const std::string& name);

          te::map::AbstractLayerPtr getOutputLayer();

        protected:

          /*! Function used to create the output dataset type */
          std::unique_ptr<te::da::DataSetType> createDataSetType(std::string dataSetName, int srid);

          /*! Function used to create the output data */
          std::unique_ptr<te::mem::DataSet> createDataSet(te::da::DataSetType* dsType, std::vector<te::gm::Geometry*>& geoms, std::vector< double >& geomsValues );

          /*! Function used to save the output dataset */
          void saveDataSet(te::mem::DataSet* dataSet, te::da::DataSetType* dsType, te::da::DataSourcePtr ds, std::string dataSetName);

        private:

          std::unique_ptr<Ui::SegmenterAdvancedOptionsWizardPageForm> m_ui;

          te::map::AbstractLayerPtr m_layer;

          te::map::AbstractLayerPtr m_outputLayer;

          std::string m_path;

          std::string m_name;
      };

    } // end namespace widgets
  }   // end namespace qt
}     // end namespace te

#endif  // __TERRALIB_QT_WIDGETS_RP_INTERNAL_SEGMENTERADVANCEDOPTIONSWIZARDPAGE_H
